---
Title: Publication procedures
Author: Kay, Jutta
Topics:
    - data/software releases
    - publication procedures
status: draft
---

# Publication procedures
Software and data publication procedures assure the quality and interoperability of data and software, the re-producability of scientific results, and the cross-fertilization between communities based on trust in the publicized science products. The following procedures have been suggested to the KM3NeT collaboration and will serve as a basis for the implementation of publication standards.

## Establishing the Open Science Committee
At this point, the KM3NeT collaboration reviews publications and contributions to conferences via the Publication Committee and Conference Committee. These committees are focusing primarily on the analysis logic, the used scientific methods and and textual/graphical representation of texts, presentations and posters, while the underlying data and software are not fully scrutinised. To overcome this gap, the KM3NeT Institute Board has decided to install an Open Science Committee. It will focus on the explicit review of the data and software included in or used for publications, and also general purpose releases of software and data in the open science regime.

## Software publication

Installation of publication procedures involves the definition of quality standards, establishing of the review procedure and implementation through a transitioning phase.

### Software quality standards

KM3NeT members are recommended to use the [software development standards](https://git.km3net.de/-/ide/project/open-data/openscienceportal/blob/master/-/pages/Softwaredevelopment.md#how-to-develop-software) already during development of the software project.

#### Core requirements
Out of these recommendations, the following condition become core requirements that have to be met for publication.

* Storage of the **source code on the KM3NeT central gitlab instance** with documentation, testing and containerisation enabled via continuous integration.
* The software is made available containerized in a **Docker container**.
* The software project is **documented**:
    * The software is listed in the internal wiki entry pointing to the gitlab hosted documentation.
    * Inline code documentation with automatic generation is installed and a reference guide for the API is provided.
    * Documentation includes a "Getting started" including installation instructions and a description of the core concepts.
* A **change procedure** is established including versioning following [Semantic Versioning 2.0.0](https://semver.org/spec/v2.0.0.html) and changelog following the gitlab workflow.
* **Coding standards** depending on the programming language are followed, using
  * the [C++ Style Guide](https://google.github.io/styleguide/cppguide.html), also for ROOT-based software,
  * the [Python Style Guide PEP-8](https://www.python.org/dev/peps/pep-0008/),
  * the [Java Style Guide](https://google.github.io/styleguide/javaguide.html)
  * and other established coding standards for further programming languages.
* the software is licensed according to the KM3NeT licensing rules.

#### Recommendations
Beyond the core requirements, the following standards are recommended, but not required for the publication procedures:
* A full tutorial is added, including [Getting started / Guides / Concepts / API](https://meet.google.com/linkredirect?authuser=0&dest=https%3A%2F%2Fdev.to%2Fojkelly%2Fthe-four-layers-to-great-documentation-dj7).
* Additional examples for applications including benchmark and test data are provided.

### Publication procedures

**1. Declare software as software candidate and pre-review**

* Authors and the relevant working group coordinator define the software as software candidate.
* Metadata is added to the software for reviewing and documentation of the publication process.
* Referees are assigned to the software release candidate by the Open Science Committee.

**2. Internal development to meet standards (after pre-review)**

Compliance of the software with the quality standards is evaluated by the refereees and the software adapted where necessary.

**3. Reviewing process**
* The assigned referees report on the status of the project and their recommendation at the working group meetings.
* The report is forwarded to the Open Science Committee for cross-checks.
* The report is submitted for collaborative feedback.

**4. Publication**
* The KM3NeT recommended license is applied and the copyright set to "the KM3NeT collaboration"
* The software released to Github and Zenodo

**5. Maintenance**
* A maintainer is assigned to the software to reply to issues on the software and initiate necessary changes.

For major further releases of the software, a shortened review process is followed. 

### Implementation

Although already software has been produced at various levels in the KM3NeT collaboration, the currently used and published software does, to a large degree, already follow the software quality standards but has not yet been officially released as KM3NeT products. Therefore, a transition procedure is implemented, where current software release candidates can follow a shortened review and publication procedure if the software has already been used in publications, indicating that the software has been thoroughly tested.

## Data publication

Data used for publications should be approved by the collaboration as well as the software involved in the data processing. In order to enable the publication of the relevant data alongside a publication, the data should meet the following standards and go through the review process.

### Standards

#### Data access and FAIRness
Data needs to be accessible and well documented.

* At time of publication, the full processing flow for the data must be accessible and reproducible for all members of the collaboration
  * All data locations, software versions and scripts must be included in a Gitlab repository.
  * The relevant environment and data locations have to be referenced in the project, which must be accessible for cross-checks.
* The data processing must be documented with the according metadata, referencing identifiers of the processing entities and activities.
* High-level data must be provided in a suitable format for data sharing, i.e. a KM3NeT public data format or custom format with sufficient metadata.

#### Data quality
* Standard tests must be performed on the completeness of the data processing and sets (sanity checks).
* Automatic testing should be used where available.
* Tests must be performed on the validity of the data and consistency of the content. These test are dependent on data type e.g. thorugh data/MC comparisons for optical event data.

#### Product type specific quality requirements
As workflows and data derivatives are also a part of the public data and production process, additional criteria might apply to specific data products

* **Event data** requires a full description of the processing workflow and annotation of all published parameters
* **Derived plots and functions** require a description of the basic data set from which data set was generated, including time range, parameter-based selections or the theoretical model.  
* **Workflows** have to include software versions, processing scripts and annotations for all major steps.

### Procedure

**1. Declare data as publication candidate**
* The data set and the intended publication is discussed in the respective working group and announced to the Open Science Committee (OSC).
  * Access to the relevant workflow and data is granted as required by the quality standards. The intended publication date is declared.
  * The data project is annotated with publication-relevant metadata and tags for the review process.
* Referees are assigned.

**2. Testing and modifications**
* Referees review the data testing, require adaptions where necessary.
* A short report on the review is produced, including the reference to the data.

**3. Review**
* The report is forwarded to the OSC for review.
* The report is forwarded to the Publication Committee for review in the analysis context (paper, proceedings etc.) and endorsed in the analysis context where applicable.
* The report is forwarded to the collaboration for review.

**4. Publication**
* Where applicable, an embargo is put on the data publication if relevant within the analysis context or general policies.
* After publication approval, the data is made available via the KM3NeT open science system, a unique identifier and version are assigned and the data is registered with public repositores.


